@@ -1,23 +1,9 @@
-/***************************************************************************
- *   Copyright © 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>       *
- *   Copyright © 2017 Jan Grulich <jgrulich@redhat.com>                    *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or         *
- *   modify it under the terms of the GNU General Public License as        *
- *   published by the Free Software Foundation; either version 2 of        *
- *   the License or (at your option) version 3 or any later version        *
- *   accepted by the membership of KDE e.V. (or its successor approved     *
- *   by the membership of KDE e.V.), which shall act as a proxy            *
- *   defined in Section 14 of version 3 of the license.                    *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
- ***************************************************************************/
+/*
+ *   SPDX-FileCopyrightText: 2013 Aleix Pol Gonzalez <aleixpol@blue-systems.com>
+ *   SPDX-FileCopyrightText: 2017 Jan Grulich <jgrulich@redhat.com>
+ *
+ *   SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
+ */
 
 #include "OdrsReviewsBackend.h"
 #include "AppStreamIntegration.h"
@@ -263,12 +249,12 @@ void OdrsReviewsBackend::parseRatings()
             QJsonObject appJsonObject = it.value().toObject();
 
             const int ratingCount =  appJsonObject.value(QLatin1String("total")).toInt();
-            QVariantMap ratingMap = { { QStringLiteral("star0"), appJsonObject.value(QLatin1String("star0")).toInt() },
-                                      { QStringLiteral("star1"), appJsonObject.value(QLatin1String("star1")).toInt() },
-                                      { QStringLiteral("star2"), appJsonObject.value(QLatin1String("star2")).toInt() },
-                                      { QStringLiteral("star3"), appJsonObject.value(QLatin1String("star3")).toInt() },
-                                      { QStringLiteral("star4"), appJsonObject.value(QLatin1String("star4")).toInt() },
-                                      { QStringLiteral("star5"), appJsonObject.value(QLatin1String("star5")).toInt() } };
+            int ratingMap[] = { appJsonObject.value(QLatin1String("star0")).toInt(),
+                                appJsonObject.value(QLatin1String("star1")).toInt(),
+                                appJsonObject.value(QLatin1String("star2")).toInt(),
+                                appJsonObject.value(QLatin1String("star3")).toInt(),
+                                appJsonObject.value(QLatin1String("star4")).toInt(),
+                                appJsonObject.value(QLatin1String("star5")).toInt() };
 
             Rating *rating = new Rating(it.key(), ratingCount, ratingMap);
             rating->setParent(this);
